@@ -1,8 +1,3 @@
-.onLoad <- function(lib, pkg) {
-    if(is.null(getOption("max.print")))
-	options(max.print = 10000)#-> show() of large matrices
-}
-
 ## --- New "logic" class -- currently using "raw" instead of "logical"
 ## LOGIC setClass("logic", contains = "raw")
 
@@ -108,10 +103,13 @@ setClass("diagonalMatrix", representation(diag = "character", "VIRTUAL"),
 	     d <- object@Dim
 	     if(d[1] != (n <- d[2])) return("matrix is not square")
 	     lx <- length(object@x)
-	     if(object@diag == "U" && lx != 0)
-		 return("diag = \"U\" (identity matrix) requires empty 'x' slot")
-	     if(object@diag == "N" && lx != n)
-		 return("diagonal matrix has 'x' slot of length != 'n'")
+	     if(object@diag == "U") {
+		 if(lx != 0)
+		     return("diag = \"U\" (identity matrix) requires empty 'x' slot")
+	     } else if(object@diag == "N") {
+		 if(lx != n)
+		     return("diagonal matrix has 'x' slot of length != 'n'")
+	     } else return("diagonal matrix 'diag' slot must be \"U\" or \"N\"")
 	     TRUE
 	 },
 	 prototype = prototype(diag = "N")
@@ -710,17 +708,20 @@ setClass("rleDiff", representation(first = "numLike", rle = "rle"),
 	     TRUE
 	 })
 
-### 2010-03-04 -- thinking about *implenting* some 'abIndex' methodology,
+### 2010-03-04 -- thinking about *implementing* some 'abIndex' methodology,
 ### I conclude that the following structure would probably be even more
 ### efficient than the "rleDiff" one :
-### for now, at least use it, and define  "seqMat" <--> "abIndex" coercions:
+### IDEA: Store subsequences in a numeric matrix of three rows, where
+### ----- one column = [from, to, by]  defining a sub seq()ence
+
+## for now, at least use it, and [TODO!] define  "seqMat" <--> "abIndex" coercions:
 setClass("seqMat", contains = "matrix",
-	 prototype = prototype(matrix(0, nrow = 2, ncol=0)),
+	 prototype = prototype(matrix(0, nrow = 3, ncol=0)),
 	 validity = function(object) {
 	     if(!is.numeric(object)) return("is not numeric")
 	     d <- dim(object)
-	     if(length(d) != 2 || d[1] != 2)
-		 return("not a	 2 x n	matrix")
+	     if(length(d) != 3 || d[1] != 3)
+		 return("not a	 3 x n	matrix")
 	     if(any(object != floor(object)))
 		 return("some entries are not integer valued")
 	     TRUE
@@ -780,11 +781,35 @@ setClass("sparseVector",
          validity = function(object) {
              n <- object@length
 	     if(any(!is.finite(i <- object@i)))# no NA's !
-		 sprintf("'i' slot is not all finite")
+		 "'i' slot is not all finite"
 	     else if(any(i < 1) || any(i > n))
-                 sprintf("'i' must be in 1:%d", n)
+		 sprintf("'i' must be in 1:%d", n)
+	     else if(is.unsorted(i, strictly=TRUE))
+		 "'i' must be sorted strictly increasingly"
              else TRUE
          })
+
+##' initialization -- ensuring that  'i' is sorted (and 'x' alongside)
+setMethod("initialize", "sparseVector", function(.Object, i, x, ...)
+      {
+	  has.x <- !missing(x)
+	  if(!missing(i)) {
+	      .Object@i <- ## (be careful to assign in all cases)
+		  if(is.unsorted(i, strictly=TRUE)) {
+		      if(is(.Object, "xsparseVector") && has.x) {
+			  si <- sort.int(i, index.return=TRUE)
+			  x <- x[si$ix]
+			  si$x
+		      }
+		      else
+			  sort.int(i, method = "quick")
+		  }
+		  else i
+	  }
+	  if(has.x) .Object@x <- x
+	  callNextMethod()
+      })
+
 .validXspVec <- function(object) {
     ## n <- object@length
     if(length(object@i) != length(object@x))
